import 'package:ocg_app/ocg_app.dart';
import 'package:ecommerce_profile/src/models/customer.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ecommerce_profile/src/repository/customer/base.dart';

abstract class CustomerCreateEvent {}

class CustomerCreateStartEvent extends CustomerCreateEvent {
  final Customer customer;
  CustomerCreateStartEvent(this.customer);
}

abstract class CustomerCreateState {}

class CustomerCreateIdleState extends CustomerCreateState {}

class CustomerCreateLoadingState extends CustomerCreateState {}

class CustomerCreateSuccessState extends CustomerCreateState {
  final String id;
  CustomerCreateSuccessState(this.id);
}

class CustomerCreateErrorState extends CustomerCreateState {
  final String error;
  CustomerCreateErrorState(this.error);
}

class CustomerCreateBloc
    extends Bloc<CustomerCreateEvent, CustomerCreateState> {
  final CustomerRepository customerRepository;
  CustomerCreateBloc(this.customerRepository)
      : super(CustomerCreateIdleState());
  @override
  Stream<CustomerCreateState> mapEventToState(
      CustomerCreateEvent event) async* {
    if (event is CustomerCreateStartEvent) {
      yield CustomerCreateLoadingState();
      AppResponse<String> response =
          await customerRepository.create(event.customer);
      if (response.isSuccess) {
        yield CustomerCreateSuccessState(response.data);
      } else {
        yield CustomerCreateErrorState(response.error);
      }
    }
  }
}
