import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ecommerce_profile/src/database/profile.dart';
import 'package:ecommerce_profile/src/models/customer.dart';
import 'package:ecommerce_profile/src/repository/customer/base.dart';

abstract class CustomerCurrentEvent {}

class CustomerCurrentRefreshEvent extends CustomerCurrentEvent {}

class CustomerCurrentSaveEvent extends CustomerCurrentEvent {
  final String id;

  CustomerCurrentSaveEvent(this.id);
}

class CustomerCurrentDeleteEvent extends CustomerCurrentEvent {
  CustomerCurrentDeleteEvent();
}

abstract class CustomerCurrentState {}

class CustomerCurrentLoadingState extends CustomerCurrentState {}

class CustomerCurrentLoadedState extends CustomerCurrentState {
  final Customer customer;

  CustomerCurrentLoadedState(this.customer);
}

class CustomerCurrentErrorState extends CustomerCurrentState {
  final String error;

  CustomerCurrentErrorState(this.error);
}

class CustomerCurrentInitialState extends CustomerCurrentState {}

class CustomerCurrentBloc
    extends Bloc<CustomerCurrentEvent, CustomerCurrentState> {
  final ProfileDatabase profileDatabase;
  final CustomerRepository customerRepository;
  CustomerCurrentBloc(this.profileDatabase, this.customerRepository)
      : super(CustomerCurrentInitialState());

  @override
  Stream<CustomerCurrentState> mapEventToState(
      CustomerCurrentEvent event) async* {
    if (event is CustomerCurrentRefreshEvent) {
      yield await getCurrentState();
    } else if (event is CustomerCurrentSaveEvent) {
      AppResponse<bool> response = await profileDatabase.saveCurrent(event.id);
      if (response.isSuccess) {
        yield await getCurrentState();
      } else {
        yield CustomerCurrentErrorState(response.error);
      }
    } else if (event is CustomerCurrentDeleteEvent) {
      AppResponse<bool> response = await profileDatabase.deleteCurrent();
      if (response.isSuccess) {
        yield CustomerCurrentErrorState("Not Exists");
      } else {
        yield CustomerCurrentErrorState(response.error);
      }
    }
  }

  Future<CustomerCurrentState> getCurrentState() async {
    AppResponse<String> profileResponse = await profileDatabase.getCurrent();
    if (profileResponse.isSuccess) {
      var response = await customerRepository.read(profileResponse.data);
      if (response.isSuccess) {
        return CustomerCurrentLoadedState(response.data);
      } else {
        return CustomerCurrentErrorState(response.error);
      }
    } else {
      return CustomerCurrentErrorState(profileResponse.error);
    }
  }
}
