import 'package:ocg_app/ocg_app.dart';
import 'package:ecommerce_profile/src/models/store.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ecommerce_profile/src/repository/store/base.dart';

abstract class StoreCreateEvent {}

class StoreCreateStartEvent extends StoreCreateEvent {
  final Store store;
  StoreCreateStartEvent(this.store);
}

abstract class StoreCreateState {}

class StoreCreateIdleState extends StoreCreateState {}

class StoreCreateLoadingState extends StoreCreateState {}

class StoreCreateSuccessState extends StoreCreateState {
  final String id;
  StoreCreateSuccessState(this.id);
}

class StoreCreateErrorState extends StoreCreateState {
  final String error;
  StoreCreateErrorState(this.error);
}

class StoreCreateBloc extends Bloc<StoreCreateEvent, StoreCreateState> {
  final StoreRepository storeRepository;
  StoreCreateBloc(this.storeRepository) : super(StoreCreateIdleState());
  @override
  Stream<StoreCreateState> mapEventToState(StoreCreateEvent event) async* {
    if (event is StoreCreateStartEvent) {
      yield StoreCreateLoadingState();
      AppResponse<String> response = await storeRepository.create(event.store);
      if (response.isSuccess) {
        yield StoreCreateSuccessState(response.data);
      } else {
        yield StoreCreateErrorState(response.error);
      }
    }
  }
}
