import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ecommerce_profile/src/database/profile.dart';
import 'package:ecommerce_profile/src/models/store.dart';
import 'package:ecommerce_profile/src/repository/store/base.dart';

abstract class StoreCurrentEvent {}

class StoreCurrentRefreshEvent extends StoreCurrentEvent {}

class StoreCurrentSaveEvent extends StoreCurrentEvent {
  final String id;

  StoreCurrentSaveEvent(this.id);
}

class StoreCurrentDeleteEvent extends StoreCurrentEvent {
  StoreCurrentDeleteEvent();
}

abstract class StoreCurrentState {}

class StoreCurrentLoadingState extends StoreCurrentState {}

class StoreCurrentLoadedState extends StoreCurrentState {
  final Store store;

  StoreCurrentLoadedState(this.store);
}

class StoreCurrentErrorState extends StoreCurrentState {
  final String error;

  StoreCurrentErrorState(this.error);
}

class StoreInitialState extends StoreCurrentState {}

class StoreCurrentBloc extends Bloc<StoreCurrentEvent, StoreCurrentState> {
  final ProfileDatabase profileDatabase;
  final StoreRepository storeRepository;
  StoreCurrentBloc(this.profileDatabase, this.storeRepository)
      : super(StoreInitialState());

  @override
  Stream<StoreCurrentState> mapEventToState(StoreCurrentEvent event) async* {
    if (event is StoreCurrentRefreshEvent) {
      yield await getCurrentState();
    } else if (event is StoreCurrentSaveEvent) {
      AppResponse<bool> response = await profileDatabase.saveCurrent(event.id);
      if (response.isSuccess) {
        yield await getCurrentState();
      } else {
        yield StoreCurrentErrorState(response.error);
      }
    } else if (event is StoreCurrentDeleteEvent) {
      AppResponse<bool> response = await profileDatabase.deleteCurrent();
      if (response.isSuccess) {
        yield StoreCurrentErrorState("Not Exists");
      } else {
        yield StoreCurrentErrorState(response.error);
      }
    }
  }

  Future<StoreCurrentState> getCurrentState() async {
    AppResponse<String> profileResponse = await profileDatabase.getCurrent();
    if (profileResponse.isSuccess) {
      var response = await storeRepository.read(profileResponse.data);
      if (response.isSuccess) {
        return StoreCurrentLoadedState(response.data);
      } else {
        return StoreCurrentErrorState(response.error);
      }
    } else {
      return StoreCurrentErrorState(profileResponse.error);
    }
  }
}
