import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ecommerce_profile/src/models/store.dart';
import 'package:ecommerce_profile/src/repository/store/base.dart';

abstract class StoreListEvent {}

class StoreListRefreshEvent extends StoreListEvent {}

abstract class StoreListState {}

class StoreListInitialState extends StoreListState {}

class StoreListLoadingState extends StoreListState {}

class StoreListLoadedState extends StoreListState {
  final List<Store> products;

  StoreListLoadedState(this.products);
}

class StoreListErrorState extends StoreListState {
  final String error;

  StoreListErrorState(this.error);
}

class StoreListBloc extends Bloc<StoreListEvent, StoreListState> {
  final StoreRepository productRepository;
  StoreListBloc(this.productRepository) : super(StoreListInitialState());

  @override
  Stream<StoreListState> mapEventToState(StoreListEvent event) async* {
    if (event is StoreListRefreshEvent) {
      yield StoreListLoadingState();
      AppResponse<List<Store>> response = await productRepository.getList();
      if (response.isSuccess) {
        yield StoreListLoadedState(response.data);
      } else {
        yield StoreListErrorState(response.error);
      }
    }
  }
}
